@@ -138,6 +138,7 @@ struct _ThunarPropertiesDialog
   GtkWidget              *link_label;
   GtkWidget              *location_label;
   GtkWidget              *origin_label;
+  GtkWidget              *created_label;
   GtkWidget              *deleted_label;
   GtkWidget              *modified_label;
   GtkWidget              *accessed_label;
@@ -454,6 +455,21 @@ thunar_properties_dialog_init (ThunarPropertiesDialog *dialog)
 
   ++row;
 
+  label = gtk_label_new (_("Created:"));
+  gtk_label_set_attributes (GTK_LABEL (label), thunar_pango_attr_list_bold ());
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, row, 1, 1);
+  gtk_widget_show (label);
+
+  dialog->created_label = g_object_new (GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
+  gtk_label_set_selectable (GTK_LABEL (dialog->created_label), TRUE);
+  exo_binding_new (G_OBJECT (dialog->created_label), "visible", G_OBJECT (label), "visible");
+  gtk_widget_set_hexpand (dialog->created_label, TRUE);
+  gtk_grid_attach (GTK_GRID (grid), dialog->created_label, 1, row, 1, 1);
+  gtk_widget_show (dialog->created_label);
+
+  ++row;
+
   label = gtk_label_new (_("Modified:"));
   gtk_label_set_attributes (GTK_LABEL (label), thunar_pango_attr_list_bold ());
   gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
@@ -707,12 +723,19 @@ thunar_properties_dialog_response (GtkDialog *dialog,
 }
 
 
+static void
+thunar_properties_file_reload_iter (gpointer data, gpointer user_data)
+{
+  ThunarFile *file = data;
+
+  thunar_file_reload (file);
+}
 
 static gboolean
 thunar_properties_dialog_reload (ThunarPropertiesDialog *dialog)
 {
   /* reload the active files */
-  g_list_foreach (dialog->files, (GFunc) (void (*)(void)) thunar_file_reload, NULL);
+  g_list_foreach (dialog->files, thunar_properties_file_reload_iter, NULL);
 
   return dialog->files != NULL;
 }
@@ -922,6 +945,8 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
   gchar             *fs_string;
   gchar             *str;
   gchar             *volume_name;
+  gchar             *volume_id;
+  gchar             *volume_label;
   ThunarFile        *file;
   ThunarFile        *parent_file;
   gboolean           show_chooser;
@@ -1066,6 +1091,21 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
       gtk_widget_hide (dialog->location_label);
     }
 
+#if GLIB_CHECK_VERSION (2, 65, 2)
+  /* update the created time */
+  date = thunar_file_get_date_string (file, THUNAR_FILE_DATE_CREATED, date_style, date_custom_style);
+  if (G_LIKELY (date != NULL))
+    {
+      gtk_label_set_text (GTK_LABEL (dialog->created_label), date);
+      gtk_widget_show (dialog->created_label);
+      g_free (date);
+    }
+  else
+#endif
+    {
+      gtk_widget_hide (dialog->created_label);
+    }
+
   /* update the deleted time */
   date = thunar_file_get_deletion_date (file, date_style, date_custom_style);
   if (G_LIKELY (date != NULL))
@@ -1143,9 +1183,15 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
         g_object_unref (gicon);
 
       volume_name = g_volume_get_name (volume);
-      gtk_label_set_text (GTK_LABEL (dialog->volume_label), volume_name);
+      volume_id = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+      volume_label= g_strdup_printf ("%s (%s)", volume_name, volume_id);
+      gtk_label_set_text (GTK_LABEL (dialog->volume_label), volume_label);
       gtk_widget_show (dialog->volume_label);
       g_free (volume_name);
+      g_free (volume_id);
+      g_free (volume_label);
+
+      g_object_unref (G_OBJECT (volume));
     }
   else
     {
@@ -1172,6 +1218,8 @@ thunar_properties_dialog_update_multiple (ThunarPropertiesDialog *dialog)
   GVolume     *tmp_volume;
   GIcon       *gicon;
   gchar       *volume_name;
+  gchar       *volume_id;
+  gchar       *volume_label;
   gchar       *display_name;
   ThunarFile  *parent_file = NULL;
   ThunarFile  *tmp_parent;
@@ -1184,6 +1232,7 @@ thunar_properties_dialog_update_multiple (ThunarPropertiesDialog *dialog)
   gtk_window_set_title (GTK_WINDOW (dialog), _("Properties"));
 
   /* widgets not used with > 1 file selected */
+  gtk_widget_hide (dialog->created_label);
   gtk_widget_hide (dialog->deleted_label);
   gtk_widget_hide (dialog->modified_label);
   gtk_widget_hide (dialog->accessed_label);
@@ -1307,9 +1356,13 @@ thunar_properties_dialog_update_multiple (ThunarPropertiesDialog *dialog)
         g_object_unref (gicon);
 
       volume_name = g_volume_get_name (volume);
-      gtk_label_set_text (GTK_LABEL (dialog->volume_label), volume_name);
+      volume_id = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+      volume_label = g_strdup_printf ("%s (%s)", volume_name, volume_id);
+      gtk_label_set_text (GTK_LABEL (dialog->volume_label), volume_label);
       gtk_widget_show (dialog->volume_label);
       g_free (volume_name);
+      g_free (volume_id);
+      g_free (volume_label);
 
       g_object_unref (G_OBJECT (volume));
     }
