@@ -65,9 +65,12 @@ typedef enum
   THUNAR_WINDOW_ACTION_VIEW_MENUBAR,
   THUNAR_WINDOW_ACTION_SHOW_HIDDEN,
   THUNAR_WINDOW_ACTION_ZOOM_IN,
-  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT,
+  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT_1,
+  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT_2,
   THUNAR_WINDOW_ACTION_ZOOM_OUT,
+  THUNAR_WINDOW_ACTION_ZOOM_OUT_ALT,
   THUNAR_WINDOW_ACTION_ZOOM_RESET,
+  THUNAR_WINDOW_ACTION_ZOOM_RESET_ALT,
   THUNAR_WINDOW_ACTION_CLEAR_DIRECTORY_SPECIFIC_SETTINGS,
   THUNAR_WINDOW_ACTION_VIEW_AS_ICONS,
   THUNAR_WINDOW_ACTION_VIEW_AS_DETAILED_LIST,
